calculate_tail_ratio: Calculate tail ratio

Description Usage Arguments Value

View source: R/calculate_tail_ratio.R

Description

This function calculates tail ratios for two overlapping normal distributed populations.

Usage

1
calculate_tail_ratio(area, mean_high, sd_high, mean_low, sd_low, cutoff)

Arguments

area

Area below or above a cutoff

mean_high

Mean of group with higher mean

sd_high

Standard deviation of group with higher mean

mean_low

Mean of group with lower mean

sd_low

Standard deviation of group with lower mean

cutoff

Cutoff value of interest, indicated in standard deviations from the higher mean group

Value

A tail ratio


cyplessen/tailRatio documentation built on July 16, 2020, 12:47 a.m.