plot_tail_ratio: Plot tail ratio

Description Usage Arguments Value

View source: R/plot_tail_ratio.R

Description

This function plots tail ratios for two normal distributed populations.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
plot_tail_ratio(
  area,
  cutoff,
  mean_high,
  sd_high,
  mean_low,
  sd_low,
  x_lab_name,
  mean_of_interest
)

Arguments

area

Area of interest, either "below" or "above" cutoff

cutoff

Cutoff value of interest, indicated in standard deviations from the higher mean group

mean_high

Mean of group with higher mean

sd_high

Standard deviation of group with higher mean

mean_low

Mean of group with lower mean

sd_low

Standard deviation of group with lower mean

x_lab_name

Name for x-Axis

mean_of_interest

Reference mean for visualization, i.e. 100 for IQ

Value

A tail ratio


cyplessen/tailRatio documentation built on July 16, 2020, 12:47 a.m.