Description Usage Arguments Value
View source: R/calculate_tail_ratio.R
This function calculates tail ratios for two overlapping normal distributed populations.
1 | calculate_tail_ratio(area, mean_high, sd_high, mean_low, sd_low, cutoff)
|
area |
Area below or above a cutoff |
mean_high |
Mean of group with higher mean |
sd_high |
Standard deviation of group with higher mean |
mean_low |
Mean of group with lower mean |
sd_low |
Standard deviation of group with lower mean |
cutoff |
Cutoff value of interest, indicated in standard deviations from the higher mean group |
A tail ratio
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.